<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>スプレッドシート</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>スプレッドシートを作成</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>新規スプレッドシートを作成</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>スプレッドシート</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>下揃え</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>選択したセルの内容を下揃えにする</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>スプレッドシート</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>中央揃え</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>選択したセルの内容を中央揃えにする</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>スプレッドシート</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>左揃え</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>選択したセルの内容を左揃えにする</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>スプレッドシート</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>右揃え</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>選択したセルの内容を右揃えにする</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>スプレッドシート</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>上揃え</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>選択したセルの内容を上揃えにする</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>スプレッドシート</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>上下中央揃え</translation>
    </message>
    <message>
      <source>Vertically center-align contents of selected cells</source>
      <translation>選択したセルの内容を縦方向中央揃えにする</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>スプレッドシート</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>スプレッドシートをエクスポート</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>スプレッドシートを CSV ファイル形式でエクスポートします</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>スプレッドシート</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>スプレッドシートをインポート</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>CSV ファイルからスプレッドシートにインポート</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>スプレッドシート</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>セルの結合</translation>
    </message>
    <message>
      <source>Merge selected cells</source>
      <translation>選択したセルを結合</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>スプレッドシート</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>エイリアスを設定</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>選択したセルのエイリアスを設定</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>スプレッドシート</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>セルの分割</translation>
    </message>
    <message>
      <source>Split previously merged cells</source>
      <translation>結合されているセルを分割</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>スプレッドシート</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>太字</translation>
    </message>
    <message>
      <source>Set text in selected cells bold</source>
      <translation>選択したセルのテキストに太字を設定</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>スプレッドシート</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>斜体</translation>
    </message>
    <message>
      <source>Set text in selected cells italic</source>
      <translation>選択したセルのテキストに斜体を設定</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>スプレッドシート</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>下線</translation>
    </message>
    <message>
      <source>Underline text in selected cells</source>
      <translation>選択したセルに下線を設定</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom Color</source>
      <translation>カスタム色</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <source>Merge cells</source>
      <translation>セルの結合</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>セルの分割</translation>
    </message>
    <message>
      <source>Left-align cell</source>
      <translation>セルを左揃え</translation>
    </message>
    <message>
      <source>Center cell</source>
      <translation>セルを中央揃え</translation>
    </message>
    <message>
      <source>Right-align cell</source>
      <translation>セルを右揃え</translation>
    </message>
    <message>
      <source>Top-align cell</source>
      <translation>セルを上揃え</translation>
    </message>
    <message>
      <source>Bottom-align cell</source>
      <translation>セルを下揃え</translation>
    </message>
    <message>
      <source>Vertically center cells</source>
      <translation>セルを上下中央揃え</translation>
    </message>
    <message>
      <source>Set bold text</source>
      <translation>太字にする</translation>
    </message>
    <message>
      <source>Set italic text</source>
      <translation>斜体にする</translation>
    </message>
    <message>
      <source>Set underline text</source>
      <translation>下線</translation>
    </message>
    <message>
      <source>Create Spreadsheet</source>
      <translation>スプレッドシートを作成</translation>
    </message>
    <message>
      <source>Set cell properties</source>
      <translation>セルのプロパティ</translation>
    </message>
    <message>
      <source>Edit cell</source>
      <translation>セルを編集</translation>
    </message>
    <message>
      <source>Insert rows</source>
      <translation>行を挿入</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>行を削除</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>列を挿入</translation>
    </message>
    <message>
      <source>Clear cell(s)</source>
      <translation>セルをクリア</translation>
    </message>
    <message>
      <source>Set foreground color</source>
      <translation>文字色を設定</translation>
    </message>
    <message>
      <source>Set background color</source>
      <translation>背景色を設定</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>セルのプロパティ</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>色 (&amp;C)</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>テキスト</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>背景色</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>配置 (&amp;A)</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation>水平方向</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>左面図</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>中心</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>右面図</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation>垂直方向</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>上面図</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>底面</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>スタイル (&amp;S)</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>太字</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>斜体</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>下線</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>単位の表示 (&amp;D)</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>単位</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>エイリアス (&amp;A)</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>エイリアス名</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>すべてのファイル (*.*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>ファイルをインポート</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>ファイルのエクスポート</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>スプレッドシートを表示</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation>セルの前景色を設定</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation>スプレッドシートのセルの前景色を設定</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation>セルの背景色を設定</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation>スプレッドシートのセルの背景色を設定</translation>
    </message>
    <message>
      <source>Spreadsheet</source>
      <translation>スプレッドシート</translation>
    </message>
    <message>
      <source>Spreadsheet does not support range selection when pasting.
Please select one cell only.</source>
      <translation>スプレッドシートは、貼り付けるときに選択範囲をサポートしていません。
セルを一つだけ選択してください。</translation>
    </message>
    <message>
      <source>Copy &amp; Paste failed</source>
      <translation>コピー＆ペーストに失敗しました</translation>
    </message>
    <message>
      <source>Alias contains invalid characters!</source>
      <translation>エイリアスに無効な文字が含まれています！</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation>Spreadsheet.B1 の代わりに
Spreadsheet.my_alias_name のように、エイリアスでセルを参照してください。</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>黒</translation>
    </message>
    <message>
      <source>White</source>
      <translation>白</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>赤</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>濃赤</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>緑</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>深緑</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>青</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>群青色</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>水色</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>濃いシアン</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>赤紫</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>濃いマゼンタ</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>黄</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>濃黄</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>灰色</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>濃灰色</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>明るい灰色</translation>
    </message>
    <message>
      <source>Custom Color</source>
      <translation>カスタム色</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>フォーム</translation>
    </message>
    <message>
      <source>&amp;Content:</source>
      <translation>内容 (&amp;C)</translation>
    </message>
    <message>
      <source>&amp;Alias:</source>
      <translation>エイリアス (&amp;A):</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation>Spreadsheet.B1 の代わりに
Spreadsheet.my_alias_name のように、エイリアスでセルを参照してください。</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Unnamed</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>行を挿入</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>行を削除</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>列を挿入</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>列を削除</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>プロパティ(&amp;P)...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>スプレッドシート</translation>
    </message>
  </context>
</TS>
